@@ -31,18 +31,14 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 	fp = fopen(fname, "rb");
 	if (fp == NULL)
 	{
-		#ifndef MAEMO
 		lprintf(__FILE__ ": failed to open: %s\n", fname);
-		#endif
 		return -1;
 	}
 
 	png_ptr = png_create_read_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
 	if (!png_ptr)
 	{
-		#ifndef MAEMO
 		lprintf(__FILE__ ": png_create_read_struct() failed\n");
-		#endif
 		fclose(fp);
 		return -1;
 	}
@@ -50,9 +46,7 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 	info_ptr = png_create_info_struct(png_ptr);
 	if (!info_ptr)
 	{
-		#ifndef MAEMO
 		lprintf(__FILE__ ": png_create_info_struct() failed\n");
-		#endif
 		goto done;
 	}
 
@@ -62,9 +56,7 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 	row_ptr = png_get_rows(png_ptr, info_ptr);
 	if (row_ptr == NULL)
 	{
-		#ifndef MAEMO
 		lprintf(__FILE__ ": png_get_rows() failed\n");
-		#endif
 		goto done;
 	}
 
@@ -78,9 +70,7 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 			unsigned short *dst = dest;
 			if (info_ptr->pixel_depth != 24)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": bg image uses %ibpp, needed 24bpp\n", info_ptr->pixel_depth);
-				#endif
 				break;
 			}
 			height = info_ptr->height;
@@ -114,17 +104,13 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 			unsigned char *dst = dest;
 			if (info_ptr->width != req_w || info_ptr->height != req_h)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": unexpected font image size %dx%d, needed %dx%d\n",
 					(int)info_ptr->width, (int)info_ptr->height, req_w, req_h);
-				#endif
 				break;
 			}
 			if (info_ptr->pixel_depth != 8)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": font image uses %ibpp, needed 8bpp\n", info_ptr->pixel_depth);
-				#endif
 				break;
 			}
 			for (y = 0; y < 16; y++)
@@ -151,17 +137,13 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 			unsigned char *dst = dest;
 			if (info_ptr->width != req_w || info_ptr->height != req_h)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": unexpected selector image size %ix%i, needed %dx%d\n",
 					(int)info_ptr->width, (int)info_ptr->height, req_w, req_h);
-				#endif
 				break;
 			}
 			if (info_ptr->pixel_depth != 8)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": selector image uses %ibpp, needed 8bpp\n", info_ptr->pixel_depth);
-				#endif
 				break;
 			}
 			for (y1 = 0; y1 < req_h; y1++)
@@ -179,9 +161,7 @@ int readpng(void *dest, const char *fname, readpng_what what, int req_w, int req
 			unsigned char *dst = dest;
 			if (info_ptr->pixel_depth != 24)
 			{
-				#ifndef MAEMO
 				lprintf(__FILE__ ": image uses %ibpp, needed 24bpp\n", info_ptr->pixel_depth);
-				#endif
 				break;
 			}
 			height = info_ptr->height;
@@ -221,9 +201,7 @@ int writepng(const char *fname, unsigned short *src, int w, int h)
 
 	f = fopen(fname, "wb");
 	if (f == NULL) {
-		#ifndef MAEMO
 		lprintf(__FILE__ ": failed to open \"%s\"\n", fname);
-		#endif
 		return -1;
 	}
 
