@@ -101,7 +101,7 @@ static int get_gameid_filename(char *buf, int size, const char *fmt, int i) {
 void set_cd_image(const char *fname)
 {
 	const char *ext = NULL;
-	
+
 	if (fname != NULL)
 		ext = strrchr(fname, '.');
 
@@ -146,14 +146,24 @@ void emu_set_default_config(void)
 	Config.PsxAuto = 1;
 
 	pl_rearmed_cbs.gpu_neon.allow_interlace = 2; // auto
+
 	pl_rearmed_cbs.gpu_peops.iUseDither = 0;
 	pl_rearmed_cbs.gpu_peops.dwActFixes = 1<<7;
 	pl_rearmed_cbs.gpu_unai.abe_hack =
 	pl_rearmed_cbs.gpu_unai.no_light =
 	pl_rearmed_cbs.gpu_unai.no_blend = 0;
+
 	memset(&pl_rearmed_cbs.gpu_peopsgl, 0, sizeof(pl_rearmed_cbs.gpu_peopsgl));
-	pl_rearmed_cbs.gpu_peopsgl.iVRamSize = 64;
+    pl_rearmed_cbs.gpu_peopsgl.iVRamSize = 64;
 	pl_rearmed_cbs.gpu_peopsgl.iTexGarbageCollection = 1;
+	pl_rearmed_cbs.gpu_peopsgl.bKeepRatio = TRUE;
+	pl_rearmed_cbs.gpu_peopsgl.bDrawDither = FALSE;
+	pl_rearmed_cbs.gpu_peopsgl.bOpaquePass = FALSE;
+	pl_rearmed_cbs.gpu_peopsgl.iFilterType = 0;
+	pl_rearmed_cbs.gpu_peopsgl.iFrameTexType = 0;
+	pl_rearmed_cbs.gpu_peopsgl.iUseMask = 0;
+	pl_rearmed_cbs.gpu_peopsgl.bAdvancedBlend = FALSE;
+	pl_rearmed_cbs.gpu_peopsgl.bUseFastMdec = FALSE;
 
 	iUseReverb = 2;
 	iUseInterpolation = 1;
