@@ -68,6 +68,10 @@ void plat_step_volume(int is_up)
 {
 }
 
-void plat_trigger_vibrate(void)
+void plat_trigger_vibrate(int is_strong)
+{
+}
+
+void plat_minimize(void)
 {
 }
