@@ -93,7 +93,7 @@ static void *displayThread(void *arg)
 		}
 	}
 
-	return 0;
+	return NULL;
 }
 
 void show_notification(char* text)
@@ -176,8 +176,10 @@ void change_disc()
 
 static DBusHandlerResult on_msg_recieved(DBusConnection* connection G_GNUC_UNUSED, DBusMessage* message, void* data)
 {
-	if (g_str_equal(dbus_message_get_path(message), CALL_SIGNAL_PATH)){
-		if (g_str_equal(dbus_message_get_member(message), CALL_INCOMING_SIG))
+	const char* msg = dbus_message_get_path(message);
+	if (msg && g_str_equal(msg, CALL_SIGNAL_PATH)){
+		const char* mbr = dbus_message_get_member(message);
+		if (mbr && g_str_equal(mbr, CALL_INCOMING_SIG))
 			show_messagebox("Paused");
 	}
 
@@ -353,6 +355,7 @@ int maemo_init(int *argc, char ***argv)
 void maemo_finish()
 {
     osso_deinitialize(osso);
+	osso = NULL;
 }
 
 void menu_loop(void)
